@@ -1,7 +1,6 @@
 package WWW::Giraffi::API;
 use strict;
 use warnings;
-use 5.010000;
 use Class::XSAccessor
   constructor => "new",
   accessors   => {
@@ -23,7 +22,7 @@ use Class::XSAccessor
 #has ssl_verify_hostname => ( is => "rw", isa => "Num");
 use Module::Pluggable search_path => [__PACKAGE__];
 
-our $VERSION                 = '0.2_04';
+our $VERSION                 = '0.13_01';
 our $AGENT                   = sprintf "%s/%s", __PACKAGE__, $VERSION;
 our $SSL_VERIFY_HOSTNAME     = 1;
 our $TIMEOUT                 = 30;
@@ -40,8 +39,7 @@ sub import {
         $pkg =~ /^${class}::([a-zA-Z]+)$/;
         my $method = lc $1;
 
-        no strict "refs";        ## no critic
-		no warnings "redefine";  ## no critic
+        no strict "refs";    ## no critic
         *{ __PACKAGE__ . "::$method" } = sub {
             my $self    = shift;
             my %options = (
@@ -85,7 +83,7 @@ WWW::Giraffi::API - Giraffi API Access Module
 
 =head1 VERSION
 
-0.2_04
+0.13_01
 
 =head1 SYNOPSIS
 
@@ -218,46 +216,6 @@ Example:
 
   my $trigger = $g->trigger;
 
-=head2 log
-
-Create WWW::Giraffi::API::Log Object
-
-Example:
-
-  my $log = $g->log;
-
-=head2 applog
-
-Create WWW::Giraffi::API::AppLog Object
-
-Example:
-
-  my $applog = $g->applog;
-
-=head2 trend
-
-Create WWW::Giraffi::API::Trend Object
-
-Example:
-
-  my $trend = $g->trend;
-
-=head2 region
-
-Create WWW::Giraffi::API::Region Object
-
-Example:
-
-  my $region = $g->region;
-
-=head2 monitoringdata
-
-Create WWW::Giraffi::API::MonitoringData Object
-
-Example:
-
-  my $monitoringdata = $g->monitoringdata;
-
 =head1 AUTHOR
 
 Akira Horimoto E<lt>emperor@gmail.comE<gt>
@@ -268,7 +226,7 @@ L<https://github.com/giraffi/giraffi/wiki>
 
 =head1 SEE ALSO
 
-L<Class::XSAccessor> L<Module::Pluggable> L<Time::Piece>
+L<Class::XSAccessor> L<Module::Pluggable>
 
 =head1 LICENSE
 
