@@ -6,20 +6,18 @@ use Time::Piece;
 
 use parent qw(WWW::Giraffi::API::Request);
 
-our $VERSION = '0.2_04';
+our $VERSION = '0.13_01';
 
-# this method has not been tested
 sub all {
 
-    my ( $self, $other_options ) = @_;
-	return $self->search(undef, $other_options);
+    my ( $self ) = @_;
+	return $self->search;
 }
 
-# this method has not been tested
 sub search {
 	# no test
-    my ( $self, $conditions, $other_options ) = @_;
-    my $arrayref = $self->get( "applogs.json", $conditions, $other_options );
+    my ( $self, $conditions ) = @_;
+    my $arrayref = $self->get( "applogs.json", $conditions );
     if ($self->use_time_piece) {
         my $tmp_arrayref = [];
         foreach my $ref(@{$arrayref}) {
@@ -31,11 +29,10 @@ sub search {
 	return $arrayref;
 }
 
-# this method has not been tested
 sub create {
 
-    my ( $self, $conditions, $other_options ) = @_;
-    return $self->post( sprintf("%s/applogs.json", $self->applogs_endpoint), undef, { applog => $conditions }, $other_options );
+    my ( $self, $conditions ) = @_;
+    return $self->post( sprintf("%s/applogs.json", $self->applogs_endpoint), undef, { applog => $conditions } );
 }
 
 1;
@@ -48,7 +45,7 @@ WWW::Giraffi::API::AppLog - Giraffi API AppLog Method Module
 
 =head1 VERSION
 
-0.2_04
+0.13_01
 
 =head1 SYNOPSIS
 
