@@ -5,74 +5,73 @@ use warnings;
 
 use parent qw(WWW::Giraffi::API::Request);
 
-our $VERSION = '0.2_04';
+our $VERSION = '0.13_01';
 
 sub all {
 
-    my ( $self, $other_options ) = @_;
-    return $self->search(undef, $other_options);
+    my ( $self ) = @_;
+    return $self->search;
 }
 
 sub search {
 
-    my ( $self, $conditions, $other_options ) = @_;
-    return $self->get( "items.json", $conditions, $other_options );
+    my ( $self, $conditions ) = @_;
+    return $self->get( "items.json", $conditions );
 }
 
 sub find {
 
-    my ( $self, $id, $other_options ) = @_;
-    return $self->get( sprintf( "items/%s.json", $id ), undef,  $other_options);
+    my ( $self, $id ) = @_;
+    return $self->get( sprintf( "items/%s.json", $id ) );
 }
 
 sub find_service {
 
-    my ( $self, $id, $conditions, $other_options ) = @_;
-    return $self->get( sprintf( "items/%s/services.json", $id ), $conditions, $other_options );
+    my ( $self, $id, $conditions ) = @_;
+    return $self->get( sprintf( "items/%s/services.json", $id ), $conditions );
 }
 
-# this method has not been tested
 sub find_agent {
 
-    my ( $self, $id, $other_options ) = @_;
-    return $self->get( sprintf( "%s/items/%s/agent", $self->monitoringdata_endpoint, $id ), undef, $other_options );
+    my ( $self, $id ) = @_;
+    return $self->get( sprintf( "%s/items/%s/agent", $self->monitoringdata_endpoint, $id ) );
 }
 
 sub create {
 
-    my ( $self, $conditions, $other_options ) = @_;
-    return $self->post( "items.json", undef, { item => $conditions }, $other_options );
+    my ( $self, $conditions ) = @_;
+    return $self->post( "items.json", undef, { item => $conditions } );
 }
 
 sub update {
 
-    my ( $self, $id, $conditions, $other_options ) = @_;
-    return $self->put( sprintf("items/%s.json", $id), undef, { item => $conditions }, $other_options );
+    my ( $self, $id, $conditions ) = @_;
+    return $self->put( sprintf("items/%s.json", $id), undef, { item => $conditions } );
 }
 
 
 sub destroy {
 
-    my ( $self, $id , $other_options ) = @_;
-    return $self->delete( sprintf("items/%s.json", $id), undef, undef, $other_options );
+    my ( $self, $id ) = @_;
+    return $self->delete( sprintf("items/%s.json", $id) );
 }
 
 sub reload {
 
-    my ( $self, $other_options ) = @_;
-    return $self->post("items/reload.json", undef, undef, $other_options);
+    my ( $self, $id ) = @_;
+    return $self->post("items/reload.json");
 }
 
 sub add_service {
 
-    my ( $self, $id, $conditions, $other_options ) = @_;
-    return $self->post(sprintf("items/%s/services.json", $id), undef, { service => $conditions }, $other_options);
+    my ( $self, $id, $conditions ) = @_;
+    return $self->post(sprintf("items/%s/services.json", $id), undef, { service => $conditions });
 }
 
 sub remove_service {
 
-    my ( $self, $id, $service_id, $other_options ) = @_;
-    return $self->delete(sprintf("items/%s/services/%s.json", $id, $service_id), undef, undef, $other_options);
+    my ( $self, $id, $service_id ) = @_;
+    return $self->delete(sprintf("items/%s/services/%s.json", $id, $service_id));
 }
 
 
@@ -86,7 +85,7 @@ WWW::Giraffi::API::Item - Giraffi API Item Method Item Module
 
 =head1 VERSION
 
-0.2_04
+0.13_01
 
 =head1 SYNOPSIS
 
@@ -268,14 +267,6 @@ Example:
   my $item_id = 1;
   $item->delete($item_id);
 
-=head2 reload
-
-Item/Service/Trigger all setting reload
-
-Example:
-
-  $item->reload;
-
 =head2 add_service
 
 Adds a new service to an item, specified by an item id parameter
